/*!
	\file	IAtlScenario.h
	\date	04 08 05
	\author	Abvent R&D copyright (c) 2005
	\author	Guillaume Boulet-Gercourt
	Header for the IAtlScenario interface.
*/
#ifndef		IAtlScenario_h
# define	IAtlScenario_h

// Basic class.
#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif
#ifndef TAtlObjectMgr_h
	#include "TAtlObjectMgr.h"
#endif
#ifndef IAtlSequence_h
	#include "IAtlSequence.h"
#endif
#ifndef IAtlAnimatedElement_h
	#include "IAtlAnimatedElement.h"
#endif
#ifndef	CAtlCamera_h
	#include "CAtlCamera.h"
#endif

namespace	AvAtl {

/// List of user guides
typedef TAtlObjectMgr<class IAtlScenarioTimeGuide>			AtlScenarioTimeGuideMgr;



/// Forward declaration
typedef TAtlObjectMgr<class IAtlSnd>		AtlSndsMgr;

/*!
	\interface IAtlUserGuide
	\date		29 11 05
	\author		Abvent R&D copyright (C) 2005
	\author		Guillaume Boulet-Gercourt
	\brief		Describes a user guide of a scenario
*/
class IAtlScenarioTimeGuide
{
public:
	/// get the time of this point
	virtual int		getTime() const = 0;

	/// set the time of this point
	virtual void	setTime(int inTime) = 0;
protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class. */
	virtual ~IAtlScenarioTimeGuide() {}
};



/// List of scenarios.
typedef TAtlObjectMgr<class IAtlScenario>			AtlScenariosMgr;


/*!
	\interface	IAtlScenario
	\date		04 08 05
	\author		Abvent R&D copyright (C) 2005
	\author		Guillaume Boulet-Gercourt
	\brief		Describes a scenario for Artlantis Studio
	A scenario has one global timeline, and one or more sequences.
	each sequence is a "camera" which "look" the timeline.

	The Timeline is accessible with the method "getAnimatedElementsMgr".
	The list of sequences is accessible with the method "getSequencesMgr".
*/
class	IAtlScenario
{
public:
	/// Put an XML representation of the scenario inside the father node.
	/** \retval the new node of the scenario.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef				putInXML(XMLNodeRef inFatherNode) const = 0;
	/// Initialize the scenario with the XML.
	/** \retval true intialization from XML succeed.
		\retval false an error occurs. */
	virtual bool					initWithXML(XMLNodeRef inFatherNode) = 0;

	/// get / set the name of the scenario
	virtual tUtf8	getName() const = 0;
	virtual void	setName(tUtf8 inName) = 0;

	/// get the sequence manager. For consulting
	virtual const AtlSequencesMgr*	getSequencesMgr() const = 0;
	/// get the sequence manager. For editing
	virtual AtlSequencesMgr*		getSequencesMgr() = 0;

	/// get the animated elements manager (it is "like" a timeline). For consulting
	virtual const AtlAnimatedElementsMgr*	getAnimatedElementsMgr() const = 0;
	/// get the animated elements manager(it is "like" a timeline). For editing.
	virtual AtlAnimatedElementsMgr*			getAnimatedElementsMgr() = 0;

	/// get / set the current frame of the scenario
	virtual int					getCurrentTime() const = 0;
	virtual void				setCurrentTime(int inFrameNbr) = 0;

	/// get / set the current sequence index of the scenario
	virtual int					getCurrentSequence() const = 0;
	virtual void				setCurrentSequence(int inIndex) = 0;

	virtual const AtlSndsMgr*	getSndsMgr() const = 0;
	virtual AtlSndsMgr*			getSndsMgr() = 0;

	/// get / set the max time (in frame number).
	virtual int					getMaxTime() const = 0;
	virtual void				setMaxTime(int inFrameNbr) = 0;

	/// get / set the number of fps
	virtual int					getFPS() const = 0;
	virtual void				setFPS(int inFPS) = 0;

	/// get / set the start time of the visible timeline
	virtual void				setVisibleTimeRangeStart(int inFrameNbr) = 0;
	virtual int					getVisibleTimeRangeStart() const = 0;

	///  get / set the end time of the visible timeline
	virtual void				setVisibleTimeRangeEnd(int inFrameNbr) = 0;
	virtual int					getVisibleTimeRangeEnd() const = 0;

	/// get the user point manager. For consulting
	virtual const AtlScenarioTimeGuideMgr*	getTimeGuidesMgr() const = 0;
	/// get the user point manager. For editing
	virtual AtlScenarioTimeGuideMgr*		getTimeGuidesMgr() = 0;
protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class. */
	virtual ~IAtlScenario() {}
};

}

#endif
